{% load compress %}
<!DOCTYPE html>
<html lang="en">
	<head>	
		<meta charset="UTF-8">
		<title>{% block title %}{{post.title}}{% endblock %}</title>
		<link
			rel="shortcut icon"
			href="/favicon.ico">
		{% compress css %}
		<link
			rel="stylesheet"
			href="{{STATIC_URL}}css/global.scss"
			media="screen"
			type="text/x-sass">
		{% endcompress %}
		<script
			type="text/javascript"
			src="http://use.typekit.com/ygp8eey.js">
		</script>
		<script type="text/javascript">
			try{Typekit.load();}catch(e){}
		</script>
	</head>
	<body>
		<div class="content">
			{% block content %}
			{{content}}
			{% endblock %}
		</div>
{% compress js %}
<script src="{{STATIC_URL}}js/jquery.js" type="text/javascript"></script>
{% endcompress %}
	</body>
</html>
