{% extends 'base.html' %}


{% block content %}
<h1>{{post.title}}</h1>
<h2>{{post.description}}</h2>
<ul>
	{% for tag in post.tags.all %}
		<li><a href="{{tag.get_absolute_url}}">{{tag.tag}}</a></li>
	{% endfor %}
</ul>
{{post.rendered_content|safe}}

{% endblock %}
