
{% load compress %}
<!DOCTYPE html>
<html lang="en">
	<head>	
		<meta charset="UTF-8">
		<title>{% block title %}{{post.title}}{% endblock %}</title>
		<link
			rel="shortcut icon"
			href="/favicon.ico">
		{% compress css %}
		<link
			rel="stylesheet"
			href="{{STATIC_URL}}css/global.scss"
			media="screen"
			type="text/x-sass">
		{% endcompress %}
		<script
			type="text/javascript"
			src="http://use.typekit.com/ygp8eey.js">
		</script>
		<script type="text/javascript">
			try{Typekit.load();}catch(e){}
		</script>
	</head>
	<body>
		<div class="content">
<div class="login">
	<form method="post">
		<h1>Login</h1>
		{% if form.non_field_errors %}
		<p class="error">
			Please enter a correct email address and password.
			Note that both fields are case-sensitive.
		</p>
		{% endif %}
		
		{% with form.username as field %}
		<fieldset class="{% if field.errors %} error {% endif %}">
			{% csrf_token %} 
			<label for="id_{{field.html_name}}">
				Email Address 
				{% if field.errors %}
					&ndash; {{field.errors|striptags}}
				{% endif %}
				</label>
			{{field}}
		</fieldset>
		{% endwith %}

		{% with form.password as field %}
		<fieldset class="{% if field.errors %} error {% endif %}">
			<label for="id_{{field.html_name}}">
				{{field.label}}
				{% if field.errors %}
					&ndash; {{field.errors|striptags}}
				{% endif %}
				</label>
			{{field}}
		</fieldset>
		{% endwith %}

		<fieldset class="button">
			<button type="submit">Login &rarr;</button>
		</fieldset>

		<p class="forgot">
			
		</p>
	</form>
</div>
		</div>
{% compress js %}
<script src="{{STATIC_URL}}js/jquery.js" type="text/javascript"></script>
{% endcompress %}
	</body>
</html>
