/*
	Inconsolata typeface was designed and released by Raph Levien (http://twitter.com/raphlinus) : http://www.levien.com/
	Used under a SIL Open Font License, 1.1
*/
@font-face {
	font-family: 'Inconsolata';
	font-style: normal;
	font-weight: normal;
	src:	local('Inconsolata'),
			url('/static/omblog/fonts/inconsolata.woff') format('woff');
}
/* 
The div and the text area
*/

fieldset.content div.writing{
	background-color: #fff;
	position: absolute;
	top: 0;
	left: 0;
}
fieldset.content div.writing textarea{
		width: 500px !important;
		outline: none;
		border: 0px none;
		margin: 0 auto;
		display: block;
		font-size: 18px;
		line-height: 28px;
		font-family: 'Inconsolata', sans-serif;
		font-style: normal;
	}
	div.writing label{
		display: none;
	}
fieldset.content div input,
fieldset.content div textarea#id_source_content{
	width: 97%;
	padding: 10px;
	font-size: 14px;
}
fieldset.content div textarea#id_source_content{
	height: 500px;
}
/* 
The activate and deactive links
*/
a.ajax_progress,
a.activate,
a.deactivate{
	width: 80px;
	height: 80px;
	display: inline-block;
	cursor: pointer;
}

	a.ajax_progress{
		background-color: #000;
		color: #fff;
		font-size: 11px;
		text-transform: uppercase;
		font-family: 'Helvetica Neue',
				Helvetica,
				Arial,
				'Sans Serif',
				sans-serif;
		line-height: 80px;
		text-align: center;
	}

	a.deactivate{
		display: none;
		background: transparent
				url(/static/omblog/img/deactivate.png)
				-10px -10px
				no-repeat;
	}

	a.activate{
		background: transparent
			url(/static/omblog/img/activate.png)
			-10px -10px
			no-repeat;
	}

		div.writing a.ajax_progress{
			position: fixed;
			top: 0;
			left: 100px;
			display: block;
		}

		div.writing a.deactivate{
			position: fixed;
			top: 0;
			left: 0;
			display: block;
		}

		div.writing a.activate{
			display: none;
		}
